mod util;
mod sensor;

use bevy::prelude::*;
use bevy::sprite::{MaterialMesh2dBundle, Mesh2dHandle, Wireframe2dConfig, Wireframe2dPlugin};
use bevy::window::WindowMode;
use bevy::color::palettes::css::*;
use bevy::diagnostic::{DiagnosticsStore, FrameTimeDiagnosticsPlugin};

use crate::sensor::SensorPlugin;
use crate::sensor::MagneticEvent;


#[derive(Component)]
struct TextChanges;

fn setup(
    mut commands: Commands,
    mut meshes: ResMut<Assets<Mesh>>,
    mut materials: ResMut<Assets<ColorMaterial>>
) {
    commands.spawn(Camera2dBundle::default());

    commands.spawn(
        TextBundle::from_sections([
            TextSection::new("FODAAAAAAA", TextStyle::default())
        ])
        .with_style(Style {
            position_type: PositionType::Absolute,
            top: Val::Px(0.0),
            left: Val::Px(0.0),
            ..default()
        })
    );
}

fn change_text(mut events: EventReader<MagneticEvent>, mut query: Query<&mut Text, With<TextChanges>>) {
    let (mut x, mut y, mut z) = (0.0, 0.0, 0.0);
    
    for event in events.read() {
        x = event.x;
        y = event.y;
        z = event.z;
    }

    for mut text in &mut query {
        text.sections[0].value = format!("x: {} y: {} z: {}", x, y, z);
    }
}

#[bevy_main]
fn main() {
    let mut app = App::new();
    app
        .add_plugins(DefaultPlugins.set(WindowPlugin {
            primary_window: Some(Window {
                resizable: false,
                mode: WindowMode::BorderlessFullscreen(MonitorSelection::Primary),
                recognize_rotation_gesture: true,
                ..default()
            }),
            ..default()
        }))
        .add_plugins(SensorPlugin)
        .add_systems(Startup, setup)
        .add_systems(Update, change_text)
        .run();
}
